// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

'use strict';
var storage = chrome.storage.local;
var $ = document.getElementById.bind(document);
var loginButton = $('login');
var accountName = $('accountName');
var password = $('password');
var emessage = $('emessage-all');
var loadingIcon = $('loading-icon');

function addClass(el, selector) {
  if (el == null) {
    return false;
  }
  return el.classList.add(selector);
};

function removeClass(el, selector) {
  if (el == null) {
    return false;
  }
  return el.classList.remove(selector);
};

function displayLoadingButton() {
  loginButton.style.cursor = 'wait';
  addClass(loadingIcon,'loader');
  loginButton.disabled = true;
};

function resetLoadingButton() {
  loginButton.style.cursor = 'pointer';
  removeClass(loadingIcon,'loader');
  loginButton.disabled = false;
};

function login(account,pwd){

  let accountName = account.trim();
  let password = pwd.toString().trim();
  const init = {
    method: 'POST',
    async: true,
    headers: {
      'Content-Type': 'application/json'
    },
    body: JSON.stringify({
      "accountName": accountName,
      "password":password,
      "grantType":"passwordV2"
    }),
    'contentType': 'json'
  };
  fetch('https://accounts.growingio.com/oauth/access_token',init)
    .then(
      function(response) {
        if (response.status === 202) {
          response.json().then(function(data) {
            storage.set({gio_account: accountName});
            storage.set({gio_auth_token: data}, function() {
              window.location.href="./secondAuth.html";
            });
          });
        } else if (response.status === 200){
          response.json().then(function(data) {
            // 因为不希望每次打开chrome都重新登录，所以只能把token存到chrome.storage.local，而不是background
            storage.set({gio_account: accountName});
            storage.set({gio_loginTime: Date.now()});
            storage.set({gio_token: data}, function() {
              window.location.href="./popup.html";
            });
          });
        } else {
          console.log('Looks like there was a problem when sign up. Status Code: ', response.status);
          resetLoadingButton();
          response.json().then(function(data) {
            console.log(data);
            if (data && data.message) {
              emessage.textContent = data.message;
            } else {
              emessage.textContent = "登录失败";
            }
          });
        }
      })
    .catch(function (error) {
      console.log('fetch events Request failed', error);
    });
}

function loginClickHandler(e){
  e.preventDefault();
  displayLoadingButton();
  let account = accountName.value || '';
  let pwd = password.value || '';
  login(account, pwd);
}

loginButton.addEventListener('click', loginClickHandler);
document.addEventListener('keydown', function (e) {
  emessage.textContent = '';
  if (13 == e.keyCode) {
    loginClickHandler(e);
  }
})
