// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
'use strict';
//import { getLocalStorage } from '../utils/Utils';

var circleLoading;
var viewMode;
var circleMode;
var circleButton;
var highlightButton;
var logoutSpan;
var loginSpan;
var circleSpan;
var highlightSpan;
var highlightInner;
var loaderSvg;
var popupContent;
var metrics;
var pageCreate;
var divs;
var account = '';
var currentMode = 'browse-mode';
var currentHighlight = 'eye-on';
var currentProjectId=null;
var currentPermission=null;
var tabId=null;        // 当前tab id

function sendMessageToContentScript(message, callback)
{
  chrome.tabs.query({active: true, currentWindow: true}, function(tabs)
  {
    chrome.tabs.sendMessage(tabs[0].id, message, function(response)
    {
      if(callback) callback(response);
    });
  });
}

function switchHighlight(highlight){
  sendMessageToContentScript({type:'switchHighlight',content: highlight}, function(response)
  {
    currentHighlight = highlight;
    var bg = chrome.extension.getBackgroundPage();   //pop可以直接执行background的函数
    if(bg){
      bg.setCircleStatus(tabId,'gio_highlight',highlight);
    }else{
      window.alert('bg is undefined：setCircleStatus/switchHighlight');
      logout();
    }
  });
  if(highlight === 'eye-on'){
    currentHighlight = highlight;
    highlightButton.style.backgroundColor='#ffbfbc';
    highlightSpan.style.color='#FF6158';
    highlightInner.style.backgroundColor='#FF6158';
    highlightInner.style.left='17px';
  }
  else{
    currentHighlight = highlight;
    highlightButton.style.backgroundColor='#9E9E9E';
    highlightSpan.style.color='#9E9E9E';
    highlightInner.style.backgroundColor='#FFF';
    highlightInner.style.left='0px';
  }
}

function getUserPermission(mode) {
  sendMessageToContentScript({type:'getUserPermission'}, function(response) {
  });
}

function switchMode(mode){
  sendMessageToContentScript({type: 'switchMode', content: mode}, function (response) {
    currentMode = mode;
    var bg = chrome.extension.getBackgroundPage();   //pop可以直接执行background的函数
    if (bg) {
      bg.setCircleStatus(tabId, 'gio_mode', mode);
    } else {
      window.alert('bg is undefined：setCircleStatus/switchMode');
      logout();
    }
  });

  if(mode === 'browse-mode'){
    viewMode.style.color ='#FFFFFF';
    viewMode.style.backgroundColor ='#383963';
    circleMode.style.color ='#333';
    circleMode.style.backgroundColor ='#FFFFFF';
    highlightButton.style.display='none';
    highlightSpan.style.display='none';
    hideOptions();
  } else{
    circleMode.style.color ='#FFFFFF';
    circleMode.style.backgroundColor ='#383963';
    viewMode.style.color ='#333';
    viewMode.style.backgroundColor ='#FFFFFF';
    highlightButton.style.display='block';
    highlightSpan.style.display='block';
    currentHighlight='eye-on';
    switchHighlight(currentHighlight);
    showOptions();
  }
}

function mountLoadingDataSvg() {
  loaderSvg.style.display = 'block';
  popupContent.style.display = 'none';
}

function unMountLoadingDataSvg() {
  loaderSvg.style.display = 'none';
  popupContent.style.display = 'block';
  showOptions();
}

//封装click事件的EventListener，否则img和span点击事件的id不是外层button的id。
function wrappedEventListener(){
  divs = document.querySelectorAll('div');
  divs[0].addEventListener('click', function(e){
    if(e.target.id === 'options' || e.target.id === 'options-span' || e.target.id === 'options-icon'){
      e.target.id = 'options';
      click(e);
    }
    else if(e.target.id === 'highlight' || e.target.id === 'highlight-inner'){
      e.target.id = 'highlight';
      click(e);
    }
    else if(e.target.id === 'help' || e.target.id === 'help-span' || e.target.id === 'help-icon'){
      e.target.id = 'help';
      click(e);
    }
    else if(e.target.id === 'page-create' || e.target.id === 'page-create-span' || e.target.id === 'page-create-icon'){
      e.target.id = 'page-create';
      click(e);
    }
    else if(e.target.id === 'metrics-manage' || e.target.id === 'metrics-manage-span' || e.target.id === 'metrics-manage-icon'){
      e.target.id = 'metrics-manage';
      click(e);
    }
    else{
      click(e);
    }
  }, false);
}

function logout(){
  switchMode('browse-mode');
  // 没有timeout会有bg的报错，不过我还不太理解那个报错的原因
  setTimeout(clearStorage, 1000);
  window.location.href="./login.html";
}

function clearStorage(){
  // 退出时 必须清除premision
  var bg = chrome.extension.getBackgroundPage();   //pop可以直接执行background的函数
  if (bg) {
    bg.setCircleStatus(tabId, 'gio_projectId', null);
    bg.setCircleStatus(tabId, 'gio_permission', null);
  }
  chrome.storage.local.remove(['gio_token','gio_account','gio_auth_token','gio_loginTime']);
}

function showOptions(){
  if(currentMode === 'circle-mode' && currentProjectId){
    metrics.style.display="block";
    pageCreate.style.display="block";
  }
}

function hideOptions(){
  metrics.style.display="none";
  pageCreate.style.display="none";
}


function click(e) {
  switch (e.target.id) {
    case 'logout':
      logout();
      break;
    case 'circle-viewMode':
      // 进入浏览模式
      if(currentMode !== 'browse-mode') {
        switchMode('browse-mode');
      }
      break;
    case 'circle-circleMode':
      // 进入圈选模式
      // 第一次进入 需要先加载content
      if(currentMode !== 'circle-mode'){
        mountLoadingDataSvg();
        var bg = chrome.extension.getBackgroundPage();   //pop可以直接执行background的函数
        if(bg){
          if(bg.getContentLoaded(tabId)){
            getUserPermission('circle-mode');
          }else{
            chrome.tabs.executeScript(null, {
              file: 'src/content.js'
            }, function(){});
          }

        }else{
          window.alert('bg is undefined：getContentLoaded');
          logout();
        }
      }
      break;
    case 'highlight':
      switchHighlight(currentHighlight === 'eye-on'?'eye-off':'eye-on');
      break;
    case 'debugger':
      //TODO: 二期： 在dev tools里面打开 web debugger
      chrome.tabs.executeScript(
        null,
        { code:"console.log('" + e.target.id + "');" },
        function () {
          //TODO: 二期： 在dev tools里面打开 web debugger
          console.log('TODO: 在dev tools里面打开 web debugger');
          window.open('../login/login.html');
        });
      window.close();
      break;
    case 'options':
      //chrome.tabs.executeScript(
      //  null,
      //  { code:"console.log('" + e.target.id + "');" },
      //  function () {
          // page style
      //   chrome.runtime.openOptionsPage();
          // pop style
          // chrome.tabs.create({ 'url': 'chrome://extensions/?options=' + chrome.runtime.id });
      //  });
      window.close();
      break;
    case 'page-create':
      sendMessageToContentScript({type:'pageCreateFromOption'}, function(response) {
      });
      break;
    case 'metrics-manage':
      chrome.tabs.create({url: `https://www.growingio.com/projects/${currentProjectId}/data-management/elements`});
      window.close();
      break;
    case 'help':
      chrome.tabs.create({url: "https://docs.growingio.com/docs/"});
      window.close();
      break;
  }
}


document.addEventListener('DOMContentLoaded', function () {
  wrappedEventListener();
});


// 监听来自content-script的消息
chrome.runtime.onMessage.addListener(function(request, sender, sendResponse)
{
  let circleMode = request.mode;
  switch (circleMode) {
    case "userPermissionCallback":
      if(request.content && request.content.length > 0){
        currentPermission = request.content;
        var bg = chrome.extension.getBackgroundPage();   //pop可以直接执行background的函数
        if (bg) {
          bg.setCircleStatus(tabId, 'gio_permission', currentPermission);
          switchMode('circle-mode');
        } else {
          window.alert('bg is undefined：setCircleStatus/switchMode');
          logout();
        }

      }else{
        window.alert('没有该项目的圈选权限!\n请联系GrowingIO的系统管理员');
        switchMode('browse-mode');
        unMountLoadingDataSvg();
      }
      break;
    case "circles-ready":
      if(currentPermission && currentPermission.length > 0) {
        switchMode('circle-mode');
      }
      break;
    case "unloading":
      currentProjectId = request.content;
      var bg = chrome.extension.getBackgroundPage();   //pop可以直接执行background的函数
      if(bg){
        bg.setCircleStatus(tabId,'gio_projectId',currentProjectId);
      }else{
        window.alert('bg is undefined：unloading');
        logout();
      }
      unMountLoadingDataSvg();
      break;
  }
});

//每次点击插件icon时先检验chrome.storage的gio_token。如果存在直接登陆成功，如果不存在先弹出登陆页面。
chrome.storage.local.get(['gio_token','gio_account','gio_loginTime'], function (result) {
  var check_gio_token = result.gio_token;
  var gio_loginTime = result.gio_loginTime;

  // 如果上一次登录是1天前，自动logout。不得已为之，中端鉴权有问题，7天有效期是失效的。
  if ((parseInt(gio_loginTime) + (3600 * 24 * 1000)) < Date.now()) {
    // 没有timeout会有bg的报错，不过我还不太理解那个报错的原因
    setTimeout(clearStorage, 1000);
    window.location.href="./login.html";
    return;
  }

  if(!check_gio_token){
    window.location.href="./login.html";
  }
  else {
    chrome.tabs.query({active: true, currentWindow: true}, function(tabs)
    {
      tabId = tabs[0].id;
      var status = null;
      var bg = chrome.extension.getBackgroundPage();   //pop可以直接执行background的函数
      if(bg){
        status = bg.getCircleStatus(tabId);
        currentProjectId = status.gio_projectId || null;
        currentPermission = status.gio_permission ||  null;
        currentMode = status.gio_mode || 'browse-mode';
        currentHighlight = status.gio_highlight ||  'eye-on';
        var $ = document.getElementById.bind(document);
        viewMode = $('circle-viewMode');
        circleMode = $('circle-circleMode');
        circleLoading = $('popup-loading-icon');
        circleButton = $('circle');
        loginSpan = $('loginSpan');
        circleSpan = $('circle-span');
        highlightSpan = $('highlight-span');
        highlightButton = $('highlight');
        highlightInner = $('highlight-inner');
        logoutSpan = $('logout');
        loaderSvg = $('start-loader');
        popupContent = $('popup-content');
        metrics=$('metrics-manage');
        pageCreate=$('page-create');
        loginSpan.textContent = result.gio_account;
        highlightButton.style.display='none';
        highlightSpan.style.display='none';
        switchMode(currentMode);
      }else{
        window.alert('bg is undefined：getCircleStatus');
        logout();
      }
    });
  }
});
