
'use strict';
var storage = chrome.storage.local;
var $ = document.getElementById.bind(document);
var verifyCodeInput = $('verifyCode');
var emessage = $('emessage');
var goBackBtn = $('goBack');
var submitButton = $('verifyCodeSbt');
var loadingIcon = $('sbt-loading-icon');

function addClass(el, selector) {
  if (el == null) {
    return false;
  }
  return el.classList.add(selector);
};

function removeClass(el, selector) {
  if (el == null) {
    return false;
  }
  return el.classList.remove(selector);
};

function displayLoadingButton() {
  submitButton.style.cursor = 'wait';
  addClass(loadingIcon,'loader');
  submitButton.disabled = true;
};

function resetLoadingButton() {
  submitButton.style.cursor = 'pointer';
  removeClass(loadingIcon,'loader');
  submitButton.disabled = false;
};

function verify(verifyCode){
  let authCode = verifyCode.toString().trim();
  storage.get(['gio_auth_token'], function (result) {
    let authToken = result.gio_auth_token.authenticationToken || '';
    const init = {
      method: 'POST',
      async: true,
      headers: {
        'Content-Type': 'application/json'
      },
      body: JSON.stringify({
        "grantType":"authenticator_token",
        "authenticationToken": authToken,
        "authenticationCode": authCode,
      }),
      'contentType': 'json'
    };
    fetch('https://accounts.growingio.com/oauth/access_token',init)
      .then(
        function(response) {
          if (response.status === 200){
            response.json().then(function(data) {
              // 因为不希望每次打开chrome都重新登录，所以只能把token存到chrome.storage.local，而不是background
              storage.set({gio_loginTime: Date.now()});
              storage.set({gio_token: data}, function() {
                window.location.href="./popup.html";
              });
            });
          } else {
            console.log('Looks like there was a problem of your authenticationCode. Status Code: ' +
              response.status);
            emessage.textContent = "验证码输入不正确，请重新输入";
            resetLoadingButton();
          }
        })
      .catch(function (error) {
        console.log('fetch events Request failed', error);
      });
  });
}

function submitHandler(e){
  e.preventDefault();
  displayLoadingButton();
  let verifyCode = verifyCodeInput.value || '';
  verify(verifyCode);
}

submitButton.addEventListener('click', submitHandler);
document.addEventListener('keydown', function (e) {
  emessage.textContent = '';
  if (13 == e.keyCode) {
    submitHandler(e);
  }
})

function goBackHandler(e) {
  e.preventDefault();
  window.location.href="./login.html";
}

goBackBtn.addEventListener('click', goBackHandler);
